/* Copyright (c) 2009 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
* @brief Example template project.
* @defgroup nrf_templates_example Example Template
*
*/

#include <stdbool.h>
#include "SEGGER_RTT.h"
#include "nrf_drv_twi.h"
#include "nrf_delay.h"
#include "app_util_platform.h"
#include "app_error.h"
#include "boards.h"
#include "ADXL375_I2C.h"


/**
 * @brief TWI master instance
 *
 * Instance of TWI master driver 
 *
 */
static const nrf_drv_twi_t m_twi_master = NRF_DRV_TWI_INSTANCE(MASTER_TWI_INST);

/**
 * @brief Initialize the master TWI
 *
 * Function used to initialize master TWI interface that would communicate with simulated EEPROM.
 *
 * @return NRF_SUCCESS or the reason of failure
 */
static ret_code_t twi_master_init(void)
{
    ret_code_t ret;
    const nrf_drv_twi_config_t config =
    {
       .scl                = TWI_SCL_M,
       .sda                = TWI_SDA_M,
       .frequency          = NRF_TWI_FREQ_400K,
       .interrupt_priority = APP_IRQ_PRIORITY_HIGH
    };

    do
    {
        ret = nrf_drv_twi_init(&m_twi_master, &config, NULL);
        if(NRF_SUCCESS != ret)
        {
            break;
        }
        nrf_drv_twi_enable(&m_twi_master);
    }while(0);
    return ret;
}


/**
 * @brief Function for application main entry.
 */
int main(void)
{
    ret_code_t ret_code;
    
    ret_code = twi_master_init();
    
    ret_code = ADXL375_I2C_init(&m_twi_master);
    
    ADXL375_I2C_data_rate_set(0x0A);
    ADXL375_I2C_offsets_set(0,0,0);
    
    int16_t x_val;
    int16_t y_val;
    int16_t z_val;
    
    
    APP_ERROR_CHECK(ret_code);
    while (true)
    {
        
        ADXL375_I2C_acc_data_read(&x_val,&y_val,&z_val);
        SEGGER_RTT_printf(0,"ACC DATA:  X: %d  Y: %d  Z: %d  \n", x_val ,y_val, z_val);
        nrf_delay_ms(100);
        
        // Do nothing.
    }
}
/** @} */
